@@ -1,8 +1,12 @@
 from __future__ import print_function
 
 import os
+import random
 import re
+import string
+import sys
 import textwrap
+import time
 
 import click
 import six
@@ -16,18 +20,21 @@ from dagster import (
     execute_pipeline_with_preset,
 )
 from dagster.cli.load_handle import handle_for_pipeline_cli_args, handle_for_repo_cli_args
-from dagster.core.definitions import Solid, solids_in_topological_order
+from dagster.core.definitions import ExecutionTargetHandle, Solid, solids_in_topological_order
+from dagster.core.definitions.partition import PartitionScheduleDefinition
 from dagster.core.definitions.pipeline import ExecutionSelector
 from dagster.core.instance import DagsterInstance
 from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
 from dagster.core.utils import make_new_run_id
 from dagster.seven import IS_WINDOWS
-from dagster.utils import DEFAULT_REPOSITORY_YAML_FILENAME, load_yaml_from_glob_list
+from dagster.utils import DEFAULT_REPOSITORY_YAML_FILENAME, load_yaml_from_glob_list, merge_dicts
 from dagster.utils.indenting_printer import IndentingPrinter
 from dagster.visualize import build_graphviz_graph
 
 from .config_scaffolder import scaffold_pipeline_config
 
+BACKFILL_TAG_LENGTH = 8
+
 
 def create_pipeline_cli_group():
     group = click.Group(name="pipeline")
@@ -401,12 +408,11 @@ def gen_partitions_from_args(partition_set, kwargs):
 
 
 def print_partition_format(partitions, indent_level):
-    if IS_WINDOWS:
-        # We cannot read the terminal (cmd/powershell/etc) window size, so just cap this at 250
-        screen_width = 250
-    else:
+    if not IS_WINDOWS and sys.stdout.isatty():
         _, tty_width = os.popen('stty size', 'r').read().split()
         screen_width = min(250, int(tty_width))
+    else:
+        screen_width = 250
     max_str_len = max(len(x.name) for x in partitions)
     spacing = 10
     num_columns = min(10, int((screen_width - indent_level) / (max_str_len + spacing)))
@@ -435,6 +441,24 @@ def validate_partition_slice(partitions, name, value):
     return index if is_start else index + 1
 
 
+def get_partition_sets_for_handle(handle):
+    check.inst_param(handle, 'handle', ExecutionTargetHandle)
+    partitions_handle = handle.build_partitions_handle()
+    scheduler_handle = handle.build_scheduler_handle()
+    partition_sets = []
+    if partitions_handle:
+        partition_sets.extend(partitions_handle.get_partition_sets())
+    if scheduler_handle:
+        partition_sets.extend(
+            [
+                schedule_def.get_partition_set()
+                for schedule_def in scheduler_handle.all_schedule_defs()
+                if isinstance(schedule_def, PartitionScheduleDefinition)
+            ]
+        )
+    return partition_sets
+
+
 @click.command(
     name='backfill',
     help='Backfill a partitioned pipeline.\n\n{instructions}'.format(
@@ -477,32 +501,24 @@ def validate_partition_slice(partitions, name, value):
         'dagster pipeline backfill log_daily_stats --to 20191201'
     ),
 )
-def pipeline_backfill_command(mode, *args, **kwargs):
-    pipeline_name = kwargs.pop('pipeline_name')
-    repo_args = {k: v for k, v in kwargs.items() if k in REPO_ARG_NAMES}
+@click.option('--noprompt', is_flag=True)
+def pipeline_backfill_command(**kwargs):
+    execute_backfill_command(kwargs, click.echo)
+
+
+def execute_backfill_command(cli_args, print_fn, instance=None):
+    pipeline_name = cli_args.pop('pipeline_name')
+    repo_args = {k: v for k, v in cli_args.items() if k in REPO_ARG_NAMES}
     if pipeline_name and not isinstance(pipeline_name, six.string_types):
         if len(pipeline_name) == 1:
             pipeline_name = pipeline_name[0]
 
-    instance = DagsterInstance.get()
+    instance = instance or DagsterInstance.get()
     handle = handle_for_repo_cli_args(repo_args)
     repository = handle.build_repository_definition()
+    noprompt = cli_args.get('noprompt')
 
-    if not pipeline_name:
-        pipeline_name = click.prompt(
-            'Select a pipeline to backfill: {}'.format(', '.join(repository.pipeline_names))
-        )
-
-    pipeline = handle.with_pipeline_name(pipeline_name).build_pipeline_definition()
-
-    partition_handle = handle.build_partitions_handle()
-
-    if not pipeline:
-        raise click.UsageError('No pipeline found')
-
-    if not partition_handle:
-        raise click.UsageError('No partitions found')
-
+    # check run launcher
     if not instance.run_launcher:
         raise click.UsageError(
             'A run launcher must be configured before running a backfill. You can configure a run '
@@ -512,54 +528,77 @@ def pipeline_backfill_command(mode, *args, **kwargs):
             'information.'
         )
 
-    if kwargs.get('partition_set'):
-        partition_set = partition_handle.get_partition_set(kwargs['partition_set'])
-    else:
-        all_partition_sets = [
-            x for x in partition_handle.get_all_partition_sets() if x.pipeline_name == pipeline.name
-        ]
-        if not all_partition_sets:
-            raise click.UsageError(
-                'Pipeline `{}` does not have partition sets defined'.format(pipeline.name)
-            )
-        if len(all_partition_sets) == 1:
-            partition_set = all_partition_sets[0]
+    # Resolve pipeline
+    if not pipeline_name and noprompt:
+        raise click.UsageError('No pipeline specified')
+    if not pipeline_name:
+        pipeline_name = click.prompt(
+            'Select a pipeline to backfill: {}'.format(', '.join(repository.pipeline_names))
+        )
+    repository = handle.build_repository_definition()
+    if not repository.has_pipeline(pipeline_name):
+        raise click.UsageError('No pipeline found named `{}`'.format(pipeline_name))
+
+    pipeline = repository.get_pipeline(pipeline_name)
+
+    # Resolve partition set
+    all_partition_sets = get_partition_sets_for_handle(handle)
+    pipeline_partition_sets = [x for x in all_partition_sets if x.pipeline_name == pipeline.name]
+    if not pipeline_partition_sets:
+        raise click.UsageError('No partition sets found for pipeline `{}`'.format(pipeline.name))
+    partition_set_name = cli_args.get('partition_set')
+    if not partition_set_name:
+        if len(pipeline_partition_sets) == 1:
+            partition_set_name = pipeline_partition_sets[0].name
+        elif noprompt:
+            raise click.UsageError('No partition set specified (see option `--partition-set`)')
         else:
             partition_set_name = click.prompt(
                 'Select a partition set to use for backfill: {}'.format(
-                    ', '.join(x.name for x in all_partition_sets)
+                    ', '.join(x.name for x in pipeline_partition_sets)
                 )
             )
-            partition_set = next(
-                (x for x in all_partition_sets if x.name == partition_set_name), None
-            )
-
+    partition_set = next((x for x in pipeline_partition_sets if x.name == partition_set_name), None)
     if not partition_set:
-        raise click.UsageError('Error, partition set not found')
+        raise click.UsageError('No partition set found named `{}`'.format(partition_set_name))
 
-    partitions = gen_partitions_from_args(partition_set, kwargs)
+    # Resolve partitions to backfill
+    partitions = gen_partitions_from_args(partition_set, cli_args)
 
-    click.echo('\n     Pipeline: {}'.format(pipeline.name))
-    click.echo('Partition set: {}'.format(partition_set.name))
-    click.echo('   Partitions: {}\n'.format(print_partition_format(partitions, indent_level=15)))
+    # Print backfill info
+    print_fn('\n     Pipeline: {}'.format(pipeline.name))
+    print_fn('Partition set: {}'.format(partition_set.name))
+    print_fn('   Partitions: {}\n'.format(print_partition_format(partitions, indent_level=15)))
 
-    if click.confirm(
+    # Confirm and launch
+    if noprompt or click.confirm(
         'Do you want to proceed with the backfill ({} partitions)?'.format(len(partitions))
     ):
-        click.echo('Launching')
+
+        backfill_tag = ''.join(
+            random.choice(string.ascii_lowercase) for x in range(BACKFILL_TAG_LENGTH)
+        )
+        print_fn('Launching runs... ')
+
         for partition in partitions:
             run = PipelineRun(
                 pipeline_name=pipeline.name,
                 run_id=make_new_run_id(),
                 selector=ExecutionSelector(pipeline.name),
                 environment_dict=partition_set.environment_dict_for_partition(partition),
-                mode=mode or 'default',
-                tags=partition_set.tags_for_partition(partition),
+                mode=cli_args.get('mode') or 'default',
+                tags=merge_dicts(
+                    {'dagster/backfill': backfill_tag}, partition_set.tags_for_partition(partition)
+                ),
                 status=PipelineRunStatus.NOT_STARTED,
             )
-            instance.run_launcher.launch_run(run)
+            instance.launch_run(run)
+            # Remove once we can handle synchronous execution... currently limited by sqlite
+            time.sleep(0.1)
+
+        print_fn('Launched backfill job `{}`'.format(backfill_tag))
     else:
-        click.echo(' Aborted!')
+        print_fn(' Aborted!')
 
 
 pipeline_cli = create_pipeline_cli_group()
