@@ -6,26 +6,22 @@ import six
 from dagster import check
 from dagster.core.errors import DagsterInvalidDefinitionError
 from dagster.core.serdes import whitelist_for_serdes
-from dagster.utils import camelcase
+from dagster.utils import camelcase, frozentags
 
 from .input import InputDefinition
 from .output import OutputDefinition
-from .utils import DEFAULT_OUTPUT, struct_to_string
+from .utils import DEFAULT_OUTPUT, struct_to_string, validate_tags
 
 
-class SolidInvocation(namedtuple('Solid', 'name alias resource_mapper_fn')):
+class SolidInvocation(namedtuple('Solid', 'name alias tags')):
     '''Identifies an instance of a solid in a pipeline dependency structure.
 
     Args:
         name (str): Name of the solid of which this is an instance.
         alias (Optional[str]): Name specific to this instance of the solid. Necessary when there are
             multiple instances of the same solid.
-        resource_mapper_fn (Optional[Callable]): Provide this function to remap resources available
-            in this pipeline to the resource keys required by the solid definition, e.g., when
-            using a library solid that expects a resource to have a different name than the name of
-            the compatible resource available in this pipeline. Should take a dictionary whose
-            keys are the resource keys provided by the pipeline and return a dictionary whose keys
-            are the resource keys required by the solid definition, interchanging the values.
+        tags (Optional[Dict[str, Any]]): Optional tags values to extend or override those
+            set on the solid definition.
 
     Examples:
 
@@ -56,17 +52,12 @@ class SolidInvocation(namedtuple('Solid', 'name alias resource_mapper_fn')):
 
     '''
 
-    def __new__(cls, name, alias=None, resource_mapper_fn=None):
+    def __new__(cls, name, alias=None, tags=None):
         name = check.str_param(name, 'name')
         alias = check.opt_str_param(alias, 'alias')
-        resource_mapper_fn = check.opt_callable_param(
-            resource_mapper_fn, 'resource_mapper_fn', SolidInvocation.default_resource_mapper_fn
-        )
-        return super(cls, SolidInvocation).__new__(cls, name, alias, resource_mapper_fn)
+        tags = frozentags(check.opt_dict_param(tags, 'tags', value_type=str, key_type=str))
 
-    @staticmethod
-    def default_resource_mapper_fn(resources, resource_deps):
-        return {r: resources.get(r) for r in resource_deps}
+        return super(cls, SolidInvocation).__new__(cls, name, alias, tags)
 
 
 class Solid(object):
@@ -80,15 +71,17 @@ class Solid(object):
             Definition of the solid.
     '''
 
-    def __init__(self, name, definition, resource_mapper_fn, container_definition=None):
+    def __init__(
+        self, name, definition, container_definition=None, tags=None,
+    ):
         from .solid import ISolidDefinition, CompositeSolidDefinition
 
         self.name = check.str_param(name, 'name')
         self.definition = check.inst_param(definition, 'definition', ISolidDefinition)
-        self.resource_mapper_fn = check.callable_param(resource_mapper_fn, 'resource_mapper_fn')
         self.container_definition = check.opt_inst_param(
             container_definition, 'container_definition', CompositeSolidDefinition
         )
+        self._additional_tags = validate_tags(tags)
 
         input_handles = {}
         for name, input_def in self.definition.input_dict.items():
@@ -143,12 +136,8 @@ class Solid(object):
         return self.definition.output_dict
 
     @property
-    def metadata(self):
-        return self.definition.metadata
-
-    @property
-    def step_metadata_fn(self):
-        return self.definition.step_metadata_fn
+    def tags(self):
+        return self.definition.tags.updated_with(self._additional_tags)
 
     def container_maps_input(self, input_name):
         if self.container_definition is None:
@@ -397,7 +386,7 @@ class DependencyStructure(object):
         '''
         Returns a Dict[SolidOutputHandle, List[SolidInputHandle]] that
         represents all the downstream inputs for each output in the
-        dictionary 
+        dictionary
         '''
         check.str_param(solid_name, 'solid_name')
         return self._solid_output_index[solid_name]
