@@ -1,18 +1,13 @@
 from collections import namedtuple
 
+from dagster.config import Field, Selector
+from dagster.config.config_type import ALL_CONFIG_BUILTINS, Array, ConfigType
+from dagster.config.field import check_opt_field_param
+from dagster.config.field_utils import Shape
+from dagster.config.iterate_types import iterate_config_types
 from dagster.core.errors import DagsterInvalidDefinitionError
-from dagster.core.types import Field, List, NamedDict, Selector
-from dagster.core.types.config import (
-    ALL_CONFIG_BUILTINS,
-    ConfigType,
-    ConfigTypeAttributes,
-    ConfigTypeKind,
-)
-from dagster.core.types.field import check_opt_field_param
-from dagster.core.types.field_utils import _ConfigHasFields, build_config_dict
-from dagster.core.types.iterate_types import iterate_config_types
-from dagster.core.types.runtime import construct_runtime_type_dictionary
-from dagster.utils import camelcase, check, ensure_single_item
+from dagster.core.types.dagster_type import construct_dagster_type_dictionary
+from dagster.utils import check, ensure_single_item
 
 from .dependency import DependencyStructure, Solid, SolidHandle, SolidInputHandle
 from .logger import LoggerDefinition
@@ -21,103 +16,6 @@ from .resource import ResourceDefinition
 from .solid import CompositeSolidDefinition, ISolidDefinition, SolidDefinition
 
 
-# Used elsewhere
-def SystemNamedDict(_name, fields, description=None):
-    '''A SystemNamedDict object is simply a NamedDict intended for internal (dagster) use.
-    '''
-    return build_config_dict(fields, description, is_system_config=True)
-
-
-def SystemDict(fields, description=None):
-    return build_config_dict(fields, description, is_system_config=True)
-
-
-class _SolidContainerConfigDict(_ConfigHasFields):
-    def __init__(self, name, fields, description=None, handle=None, child_solids_config_field=None):
-        self._handle = check.opt_inst_param(handle, 'handle', SolidHandle)
-        self._child_solids_config_field = check.opt_inst_param(
-            child_solids_config_field, 'child_solids_config_field', Field
-        )
-
-        super(_SolidContainerConfigDict, self).__init__(
-            key=name,
-            name=name,
-            kind=ConfigTypeKind.DICT,
-            fields=fields,
-            description=description,
-            type_attributes=ConfigTypeAttributes(is_system_config=True),
-        )
-
-    @property
-    def handle(self):
-        '''A solid handle ref to the composite solid that is associated with this config schema
-        (e.g., this is the top-level config object for a composite solid or pipeline)
-        '''
-        return self._handle
-
-    @property
-    def child_solids_config_field(self):
-        '''We stash the config schema for the children of composite solids here so that we can
-        continue schema traversal even when masked at the top level of config
-        '''
-        return self._child_solids_config_field
-
-
-def SolidContainerConfigDict(
-    name, fields, description=None, handle=None, child_solids_config_field=None
-):
-    class _SolidContainerConfigDictInternal(_SolidContainerConfigDict):
-        def __init__(self):
-            super(_SolidContainerConfigDictInternal, self).__init__(
-                name=name,
-                fields=fields,
-                description=description,
-                handle=handle,
-                child_solids_config_field=child_solids_config_field,
-            )
-
-    return _SolidContainerConfigDictInternal
-
-
-def SystemSelector(fields, description=None):
-    return Selector(fields, description, ConfigTypeAttributes(is_system_config=True))
-
-
-class _SolidConfigDict(_ConfigHasFields):
-    def __init__(self, name, fields, description):
-
-        super(_SolidConfigDict, self).__init__(
-            key=name,
-            name=name,
-            kind=ConfigTypeKind.DICT,
-            fields=fields,
-            description=description,
-            type_attributes=ConfigTypeAttributes(is_system_config=True),
-        )
-
-
-def SolidConfigDict(name, fields, description=None):
-    from dagster.core.types.field_utils import check_user_facing_fields_dict
-
-    check_user_facing_fields_dict(fields, 'NamedDict named "{}"'.format(name))
-
-    class _SolidConfigDictInternal(_SolidConfigDict):
-        def __init__(self):
-            super(_SolidConfigDictInternal, self).__init__(
-                name=name, fields=fields, description=description
-            )
-
-    return _SolidConfigDictInternal
-
-
-def is_solid_dict(obj):
-    return isinstance(obj, _SolidConfigDict)
-
-
-def is_solid_container_config(obj):
-    return isinstance(obj, _SolidContainerConfigDict)
-
-
 def _is_selector_field_optional(config_type):
     check.inst_param(config_type, 'config_type', ConfigType)
     if len(config_type.fields) > 1:
@@ -133,9 +31,9 @@ def define_resource_dictionary_cls(resource_defs):
     fields = {}
     for resource_name, resource_def in resource_defs.items():
         if resource_def.config_field:
-            fields[resource_name] = Field(SystemDict({'config': resource_def.config_field}))
+            fields[resource_name] = Field(Shape({'config': resource_def.config_field}))
 
-    return SystemDict(fields=fields)
+    return Shape(fields=fields)
 
 
 def remove_none_entries(ddict):
@@ -147,7 +45,7 @@ def define_solid_config_cls(config_field, inputs_field, outputs_field):
     check_opt_field_param(inputs_field, 'inputs_field')
     check_opt_field_param(outputs_field, 'outputs_field')
 
-    return SystemDict(
+    return Shape(
         remove_none_entries(
             {'config': config_field, 'inputs': inputs_field, 'outputs': outputs_field}
         ),
@@ -182,38 +80,29 @@ def define_logger_dictionary_cls(creation_data):
 
     for logger_name, logger_definition in creation_data.logger_defs.items():
         fields[logger_name] = Field(
-            SystemDict(remove_none_entries({'config': logger_definition.config_field}),),
-            is_optional=True,
+            Shape(remove_none_entries({'config': logger_definition.config_field}),),
+            is_required=False,
         )
 
-    return SystemDict(fields)
+    return Shape(fields)
 
 
 def define_environment_cls(creation_data):
     check.inst_param(creation_data, 'creation_data', EnvironmentClassCreationData)
-    pipeline_name = camelcase(creation_data.pipeline_name)
 
-    return SolidContainerConfigDict(
-        name='{pipeline_name}.Mode.{mode_name}.Environment'.format(
-            pipeline_name=pipeline_name, mode_name=camelcase(creation_data.mode_definition.name)
-        ),
+    return Shape(
         fields=remove_none_entries(
             {
                 'solids': Field(
                     define_solid_dictionary_cls(
-                        '{pipeline_name}.SolidsConfigDictionary'.format(
-                            pipeline_name=pipeline_name
-                        ),
-                        creation_data.solids,
-                        creation_data.dependency_structure,
-                        creation_data.pipeline_name,
+                        creation_data.solids, creation_data.dependency_structure,
                     )
                 ),
                 'storage': Field(
-                    define_storage_config_cls(creation_data.mode_definition), is_optional=True,
+                    define_storage_config_cls(creation_data.mode_definition), is_required=False,
                 ),
                 'execution': Field(
-                    define_executor_config_cls(creation_data.mode_definition), is_optional=True,
+                    define_executor_config_cls(creation_data.mode_definition), is_required=False,
                 ),
                 'loggers': Field(define_logger_dictionary_cls(creation_data)),
                 'resources': Field(
@@ -231,12 +120,10 @@ def define_storage_config_cls(mode_definition):
 
     for storage_def in mode_definition.system_storage_defs:
         fields[storage_def.name] = Field(
-            SystemDict(
-                fields={'config': storage_def.config_field} if storage_def.config_field else {},
-            )
+            Shape(fields={'config': storage_def.config_field} if storage_def.config_field else {},)
         )
 
-    return SystemSelector(fields)
+    return Selector(fields)
 
 
 def define_executor_config_cls(mode_definition):
@@ -246,12 +133,12 @@ def define_executor_config_cls(mode_definition):
 
     for executor_def in mode_definition.executor_defs:
         fields[executor_def.name] = Field(
-            SystemDict(
+            Shape(
                 fields={'config': executor_def.config_field} if executor_def.config_field else {},
             )
         )
 
-    return SystemSelector(fields)
+    return Selector(fields)
 
 
 def get_inputs_field(solid, handle, dependency_structure):
@@ -278,7 +165,7 @@ def get_inputs_field(solid, handle, dependency_structure):
     if not inputs_field_fields:
         return None
 
-    return Field(SystemDict(inputs_field_fields))
+    return Field(Shape(inputs_field_fields))
 
 
 def get_outputs_field(solid, handle):
@@ -294,81 +181,68 @@ def get_outputs_field(solid, handle):
     for name, out in solid_def.output_dict.items():
         if out.runtime_type.output_materialization_config:
             output_dict_fields[name] = Field(
-                type(out.runtime_type.output_materialization_config.schema_type), is_optional=True
+                out.runtime_type.output_materialization_config.schema_type, is_required=False
             )
 
-    output_entry_dict = SystemDict(output_dict_fields)
+    output_entry_dict = Shape(output_dict_fields)
 
-    return Field(List[output_entry_dict], is_optional=True)
+    return Field(Array(output_entry_dict), is_required=False)
 
 
-def define_isolid_field(solid, handle, dependency_structure, pipeline_name):
+def filtered_system_dict(fields):
+    return Field(Shape(remove_none_entries(fields)))
+
+
+def construct_leaf_solid_config(solid, handle, dependency_structure, config_field):
+    return filtered_system_dict(
+        {
+            'inputs': get_inputs_field(solid, handle, dependency_structure),
+            'outputs': get_outputs_field(solid, handle),
+            'config': config_field,
+        }
+    )
+
+
+def define_isolid_field(solid, handle, dependency_structure):
     check.inst_param(solid, 'solid', Solid)
     check.inst_param(handle, 'handle', SolidHandle)
 
-    check.str_param(pipeline_name, 'pipeline_name')
+    # All solids regardless of compositing status get the same inputs and outputs
+    # config. The only thing the varies is on extra element of configuration
+    # 1) Vanilla solid definition: a 'config' key with the config_field as the value
+    # 2) Composite with field mapping: a 'config' key with the config_field of
+    #    the config mapping
+    # 3) Composite without field mapping: a 'solids' key with recursively defined
+    #    solids dictionary
 
-    if isinstance(solid.definition, CompositeSolidDefinition):
-        composite_def = solid.definition
-        child_solids_config_field = Field(
-            define_solid_dictionary_cls(
-                '{pipeline_name}.CompositeSolidsDict.{solid_handle}'.format(
-                    pipeline_name=camelcase(pipeline_name), solid_handle=handle.camelcase()
-                ),
-                composite_def.solids,
-                composite_def.dependency_structure,
-                pipeline_name,
-                handle,
-            )
+    if isinstance(solid.definition, SolidDefinition):
+        return construct_leaf_solid_config(
+            solid, handle, dependency_structure, solid.definition.config_field
         )
 
-        composite_config_dict = {
-            'inputs': get_inputs_field(solid, handle, dependency_structure),
-            'outputs': get_outputs_field(solid, handle),
-        }
+    composite_def = check.inst(solid.definition, CompositeSolidDefinition)
 
-        # Mask solid config for solids beneath this level if config mapping is provided
-        if composite_def.has_config_mapping:
-            composite_config_dict['config'] = composite_def.config_mapping.config_field or Field(
-                NamedDict(
-                    '{pipeline_name}.CompositeSolidsConfig.{solid_handle}'.format(
-                        pipeline_name=camelcase(pipeline_name), solid_handle=handle.camelcase()
-                    ),
-                    {},
-                )
-            )
-        else:
-            composite_config_dict['solids'] = child_solids_config_field
-
-        return Field(
-            SolidContainerConfigDict(
-                '{name}CompositeSolidConfig'.format(name=str(handle)),
-                remove_none_entries(composite_config_dict),
-                handle=handle,
-                child_solids_config_field=child_solids_config_field,
-            )
+    if composite_def.has_config_mapping:
+        return construct_leaf_solid_config(
+            solid, handle, dependency_structure, composite_def.config_mapping.config_field
         )
-
-    elif isinstance(solid.definition, SolidDefinition):
-        solid_config_type = define_solid_config_cls(
-            solid.definition.config_field,
-            inputs_field=get_inputs_field(solid, handle, dependency_structure),
-            outputs_field=get_outputs_field(solid, handle),
-        )
-        return Field(solid_config_type)
     else:
-        check.invariant(
-            'Unexpected ISolidDefinition type {type}'.format(type=type(solid.definition))
+        return filtered_system_dict(
+            {
+                'inputs': get_inputs_field(solid, handle, dependency_structure),
+                'outputs': get_outputs_field(solid, handle),
+                'solids': Field(
+                    define_solid_dictionary_cls(
+                        composite_def.solids, composite_def.dependency_structure, handle,
+                    )
+                ),
+            }
         )
 
 
-def define_solid_dictionary_cls(
-    name, solids, dependency_structure, pipeline_name, parent_handle=None
-):
-    check.str_param(name, 'name')
+def define_solid_dictionary_cls(solids, dependency_structure, parent_handle=None):
     check.list_param(solids, 'solids', of_type=Solid)
     check.inst_param(dependency_structure, 'dependency_structure', DependencyStructure)
-    check.str_param(pipeline_name, 'pipeline_name')
     check.opt_inst_param(parent_handle, 'parent_handle', SolidHandle)
 
     fields = {}
@@ -378,10 +252,9 @@ def define_solid_dictionary_cls(
                 solid,
                 SolidHandle(solid.name, solid.definition.name, parent_handle),
                 dependency_structure,
-                pipeline_name,
             )
 
-    return SolidConfigDict(name, fields)
+    return Shape(fields)
 
 
 def iterate_solid_def_types(solid_def):
@@ -400,7 +273,7 @@ def iterate_solid_def_types(solid_def):
 
 
 def _gather_all_schemas(solid_defs):
-    runtime_types = construct_runtime_type_dictionary(solid_defs)
+    runtime_types = construct_dagster_type_dictionary(solid_defs)
     for rtt in runtime_types.values():
         if rtt.input_hydration_config:
             for ct in iterate_config_types(rtt.input_hydration_config.schema_type):
@@ -426,14 +299,15 @@ def construct_config_type_dictionary(solid_defs, environment_type):
     check.list_param(solid_defs, 'solid_defs', ISolidDefinition)
     check.inst_param(environment_type, 'environment_type', ConfigType)
 
-    type_dict_by_name = {t.name: t for t in ALL_CONFIG_BUILTINS}
+    type_dict_by_name = {t.given_name: t for t in ALL_CONFIG_BUILTINS}
+    # type_dict_by_name = {t.given_name: t for t in ALL_CONFIG_BUILTINS if t.given_name}
     type_dict_by_key = {t.key: t for t in ALL_CONFIG_BUILTINS}
     all_types = list(_gather_all_config_types(solid_defs, environment_type)) + list(
         _gather_all_schemas(solid_defs)
     )
 
     for config_type in all_types:
-        name = config_type.name
+        name = config_type.given_name
         if name and name in type_dict_by_name:
             if type(config_type) is not type(type_dict_by_name[name]):
                 raise DagsterInvalidDefinitionError(
@@ -443,7 +317,7 @@ def construct_config_type_dictionary(solid_defs, environment_type):
                     ).format(name=name)
                 )
         elif name:
-            type_dict_by_name[config_type.name] = config_type
+            type_dict_by_name[name] = config_type
 
         type_dict_by_key[config_type.key] = config_type
 
