@@ -4,25 +4,26 @@ from collections import OrderedDict
 import six
 
 from dagster import check
+from dagster.config.field_utils import check_user_facing_opt_config_param
 from dagster.core.definitions.config import ConfigMapping
 from dagster.core.errors import DagsterInvalidDefinitionError
-from dagster.core.types.field_utils import check_user_facing_opt_field_param
 from dagster.utils import frozendict, frozenlist
+from dagster.utils.backcompat import canonicalize_backcompat_args
 
 from .container import IContainSolids, create_execution_structure, validate_dependency_dict
 from .dependency import SolidHandle
 from .input import InputDefinition, InputMapping
 from .output import OutputDefinition, OutputMapping
-from .utils import check_valid_name
+from .utils import check_valid_name, validate_tags
 
 
 class ISolidDefinition(six.with_metaclass(ABCMeta)):
     def __init__(
-        self, name, input_defs, output_defs, description=None, metadata=None, positional_inputs=None
+        self, name, input_defs, output_defs, description=None, tags=None, positional_inputs=None
     ):
         self._name = check_valid_name(name)
         self._description = check.opt_str_param(description, 'description')
-        self._metadata = check.opt_dict_param(metadata, 'metadata', key_type=str)
+        self._tags = validate_tags(tags)
         self._input_defs = frozenlist(input_defs)
         self._input_dict = frozendict({input_def.name: input_def for input_def in input_defs})
         check.invariant(len(self._input_defs) == len(self._input_dict), 'Duplicate input def names')
@@ -47,8 +48,8 @@ class ISolidDefinition(six.with_metaclass(ABCMeta)):
         return self._description
 
     @property
-    def metadata(self):
-        return self._metadata
+    def tags(self):
+        return self._tags
 
     @property
     def input_defs(self):
@@ -138,7 +139,14 @@ class ISolidDefinition(six.with_metaclass(ABCMeta)):
     def alias(self, name):
         from .composition import CallableSolidNode
 
-        return CallableSolidNode(self, name)
+        check.str_param(name, 'name')
+
+        return CallableSolidNode(self, given_alias=name)
+
+    def tag(self, tags):
+        from .composition import CallableSolidNode
+
+        return CallableSolidNode(self, tags=validate_tags(tags))
 
 
 class SolidDefinition(ISolidDefinition):
@@ -164,10 +172,31 @@ class SolidDefinition(ISolidDefinition):
             of the solid's ``output_defs``, and additionally may yield other types of Dagster
             events, including :py:class:`Materialization` and :py:class:`ExpectationResult`.
         output_defs (List[OutputDefinition]): Outputs of the solid.
-        config_field (Optional[Field]): Defines how the solid may be configured.
+        config (Optional[Any]): The schema for the config. Configuration data available in
+            `init_context.solid_config`.
+
+            This value can be:
+
+            1. A Python primitive type that resolve to dagster config
+               types: int, float, bool, str.
+
+            2. A dagster config type: Int, Float, Bool,
+               :py:class:`Array`, :py:class:`Noneable`, :py:class:`Selector`,
+               :py:class:`Shape`, :py:class:`Permissive`, etc
+
+            3. A bare python dictionary, which is wrapped in :py:class:`Shape`. Any
+               values in the dictionary get resolved by the same rules, recursively.
+
+            4. A bare python list of length one which itself is config type.
+               Becomes :py:class:`Array` with list element as an argument.
+
+            5. A instance of :py:class:`Field`.
+
         description (Optional[str]): Human-readable description of the solid.
-        metadata (Optional[Dict[Any, Any]]): Arbitrary metadata for the solid. Frameworks may
-            expect and require certain metadata to be attached to a solid.
+        tags (Optional[Dict[str, Any]]): Arbitrary metadata for the solid. Frameworks may
+            expect and require certain metadata to be attached to a solid. Users should generally
+            not set metadata directly. Values that are not strings will be json encoded and must meet
+            the criteria that `json.loads(json.dumps(value)) == value`.
         required_resource_keys (Optional[Set[str]]): Set of resources handles required by this
             solid.
         positional_inputs (Optional[List[str]]): The positional order of the input names if it
@@ -194,30 +223,25 @@ class SolidDefinition(ISolidDefinition):
         input_defs,
         compute_fn,
         output_defs,
-        config_field=None,
+        config=None,
         description=None,
-        metadata=None,
+        tags=None,
         required_resource_keys=None,
-        step_metadata_fn=None,
         positional_inputs=None,
+        metadata=None,
     ):
         self._compute_fn = check.callable_param(compute_fn, 'compute_fn')
-        self._config_field = check_user_facing_opt_field_param(
-            config_field,
-            'config_field',
-            'of a SolidDefinition or @solid named "{name}"'.format(name=name),
+        self._config_field = check_user_facing_opt_config_param(config, 'config',)
+        self._required_resource_keys = frozenset(
+            check.opt_set_param(required_resource_keys, 'required_resource_keys', of_type=str)
         )
-        self._required_resource_keys = check.opt_set_param(
-            required_resource_keys, 'required_resource_keys', of_type=str
-        )
-        self._step_metadata_fn = check.opt_callable_param(step_metadata_fn, 'step_metadata_fn')
 
         super(SolidDefinition, self).__init__(
             name=name,
             input_defs=check.list_param(input_defs, 'input_defs', InputDefinition),
             output_defs=check.list_param(output_defs, 'output_defs', OutputDefinition),
             description=description,
-            metadata=metadata,
+            tags=canonicalize_backcompat_args(tags, 'tags', metadata, 'metadata'),
             positional_inputs=positional_inputs,
         )
 
@@ -231,11 +255,7 @@ class SolidDefinition(ISolidDefinition):
 
     @property
     def required_resource_keys(self):
-        return self._required_resource_keys
-
-    @property
-    def step_metadata_fn(self):
-        return self._step_metadata_fn
+        return frozenset(self._required_resource_keys)
 
     @property
     def has_config_entry(self):
@@ -279,7 +299,10 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
             level dict are either string names of solids or SolidInvocations. The values
             are dicts that map input names to DependencyDefinitions.
         description (Optional[str]): Human readable description of this composite solid.
-        metadata (Optional[Dict[Any, Any]]): Arbitrary metadata for the composite solid. Frameworks
+        tags (Optional[Dict[str, Any]]): Arbitrary metadata for the solid. Frameworks may
+            expect and require certain metadata to be attached to a solid. Users should generally
+            not set metadata directly. Values that are not strings will be json encoded and must meet
+            the criteria that `json.loads(json.dumps(value)) == value`.
             may expect and require certain metadata to be attached to a solid.
         positional_inputs (Optional[List[str]]): The positional order of the inputs if it
             differs from the order of the input mappings
@@ -313,7 +336,7 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
         config_mapping=None,
         dependencies=None,
         description=None,
-        metadata=None,
+        tags=None,
         positional_inputs=None,
     ):
         check.str_param(name, 'name')
@@ -344,7 +367,7 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
             input_defs=input_def_list,
             output_defs=output_defs,
             description=description,
-            metadata=metadata,
+            tags=tags,
             positional_inputs=positional_inputs,
         )
 
@@ -406,8 +429,7 @@ class CompositeSolidDefinition(ISolidDefinition, IContainSolids):
         required_resource_keys = set()
         for solid in self.solids:
             required_resource_keys.update(solid.definition.required_resource_keys)
-
-        return required_resource_keys
+        return frozenset(required_resource_keys)
 
     @property
     def has_config_mapping(self):
