@@ -13,13 +13,25 @@ def create_compute_step(pipeline_name, environment_config, solid, step_inputs, h
     check.list_param(step_inputs, 'step_inputs', of_type=StepInput)
     check.opt_inst_param(handle, 'handle', SolidHandle)
 
+    # the environment config has the solid output name configured
+    config_output_names = set()
+    current_handle = handle
+    while current_handle:
+        solid_config = environment_config.solids.get(current_handle.to_string())
+        current_handle = current_handle.parent
+        for output_spec in solid_config.outputs:
+            config_output_names = config_output_names.union(output_spec.keys())
+
     return ExecutionStep(
         pipeline_name=pipeline_name,
         key_suffix='compute',
         step_inputs=step_inputs,
         step_outputs=[
             StepOutput(
-                name=name, runtime_type=output_def.runtime_type, optional=output_def.optional
+                name=name,
+                runtime_type=output_def.runtime_type,
+                optional=output_def.optional,
+                should_materialize=name in config_output_names,
             )
             for name, output_def in solid.definition.output_dict.items()
         ],
@@ -28,9 +40,7 @@ def create_compute_step(pipeline_name, environment_config, solid, step_inputs, h
         ),
         kind=StepKind.COMPUTE,
         solid_handle=handle,
-        metadata=solid.step_metadata_fn(environment_config)
-        if solid.step_metadata_fn
-        else solid.metadata,
+        tags=solid.tags,
     )
 
 
